pub struct PossessionChallenge { /* private fields */ }Expand description
NDNCERT possession challenge handler.
The client must:
- Sign the
request_idbytes with the private key corresponding to a certificate intrusted_certs. - Submit the certificate name and the base64url-encoded signature as
cert_nameandsignatureparameters.
Implementations
Sourceimpl PossessionChallenge
impl PossessionChallenge
Sourcepub fn new(trusted_certs: Vec<Certificate>) -> Self
pub fn new(trusted_certs: Vec<Certificate>) -> Self
Create a challenge that accepts possession of any cert in trusted_certs.